# Experiment Notebook (`enb`)

## enb: efficient and reproducible experiments.

The `enb` Python 3 library that can help you:

- Design and run any type of computer-based experiment. Quickly.
- Analyze, plot and report new and existing experiment results. Clearly.
- Export a reproducible experiment, and/or share meaningful raw data. Easily.

## Quickstart resources

- A tutorial-like **user manual** is available at https://miguelinux314.github.io/experiment-notebook.
- Detailed **installation instructions** can be found
  at https://miguelinux314.github.io/experiment-notebook/installation.html.
- The **changelog** between `enb` versions is available
  at https://github.com/miguelinux314/experiment-notebook/blob/master/CHANGELOG.md.

## Installation

The latest stable version of `enb` can be installed by running:

    `pip install enb`

On Windows, the ray library might need to be installed manually first. See the following link
for updated information on how to do it: 

    `https://docs.ray.io/en/master/installation.html`

